var indexSectionsWithContent =
{
  0: "_abcdefghilmnprstuvx",
  1: "abdefinrstuv",
  2: "cptv",
  3: "_bdfprtuv",
  4: "_abcdefghilpstu",
  5: "bcdefhilmnprstvx",
  6: "c"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Pages"
};

